summaryrefslogtreecommitdiffstats
path: root/knode/kncollectionviewitem.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'knode/kncollectionviewitem.cpp')
-rw-r--r--knode/kncollectionviewitem.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/knode/kncollectionviewitem.cpp b/knode/kncollectionviewitem.cpp
index 245ea777..4c1f4b7a 100644
--- a/knode/kncollectionviewitem.cpp
+++ b/knode/kncollectionviewitem.cpp
@@ -32,8 +32,8 @@
#include "knconfigmanager.h"
-KNCollectionViewItem::KNCollectionViewItem( KFolderTree *tqparent, Protocol protocol, Type type) :
- KFolderTreeItem(tqparent, TQString(), protocol, type), coll(0)
+KNCollectionViewItem::KNCollectionViewItem( KFolderTree *parent, Protocol protocol, Type type) :
+ KFolderTreeItem(parent, TQString(), protocol, type), coll(0)
{
setIcon();
}
@@ -137,7 +137,7 @@ void KNCollectionViewItem::paintCell( TQPainter * p, const TQColorGroup & cg,int
if (px)
pxWidth += px->width();
// temporary set the squeezed text and use the tqparent class to paint it
TQString curText = text( column );
if ( p->fontMetrics().width( curText ) > width - pxWidth ) {
setText( column, squeezeFolderName( curText, p->fontMetrics(), width - pxWidth ) );
@@ -137,7 +137,7 @@ void KNCollectionViewItem::paintCell( TQPainter * p, const TQColorGroup & cg,int
if (px)
pxWidth += px->width();
- // temporary set the squeezed text and use the tqparent class to paint it
+ // temporary set the squeezed text and use the parent class to paint it
TQString curText = text( column );
if ( p->fontMetrics().width( curText ) > width - pxWidth ) {